@@ -1,10 +1,8 @@
 from ipywidgets import Widget
 from traitlets import Unicode, List, Bool, Dict, Any, validate
-
 from ._type import type_detect
 from ._layout import validate_view, validate_columns, validate_rowpivots, validate_columnpivots, validate_aggregates, validate_sort
 from ._schema import validate_schema
-from ._config import config
 
 
 class PerspectiveWidget(Widget):
@@ -20,7 +18,7 @@ class PerspectiveWidget(Widget):
 
     _dat_orig = Any()
 
-    datasrc = Unicode(default_value='').tag(sync=True)
+    datasrc = Unicode(default_value='static').tag(sync=True)
     schema = Dict(default_value={}).tag(sync=True)
     view = Unicode('hypergrid').tag(sync=True)
     columns = List(default_value=[]).tag(sync=True)
@@ -32,24 +30,23 @@ class PerspectiveWidget(Widget):
     settings = Bool(True).tag(sync=True)
     dark = Bool(False).tag(sync=True)
 
-    # FIXME
-    helper_config = Dict(default_value={}).tag(sync=True)
+    def delete(self):
+        self.send({'type': 'delete'})
 
-    def _get_data(self):
-        return self._dat_orig
+    def update(self, data):
+        typ, dat_orig, data_new = type_detect(data)
+        self.send({'type': 'update', 'data': data_new})
 
-    def _set_data(self, value):
+    def load(self, value):
         typ, dat_orig, dat = type_detect(value)
-        if isinstance(dat, str):
+
+        if typ == 'url':
             # unconvertable, must be http/ws/sio/comm
-            data_src = dat
             self._dat_orig = dat_orig
             dat = []
             dat_orig = ''
         else:
-            data_src = ''
             self._dat_orig = dat_orig
-            self.datasrc = 'static'
 
         if len(dat_orig) and typ:
             s = validate_schema(dat_orig, typ)
@@ -57,7 +54,7 @@ class PerspectiveWidget(Widget):
             if not self.columns:
                 columns = list(map(lambda x: str(x), s.keys()))
                 if not self.rowpivots and self.view != 'hypergrid':
-                    if 'index' in dat_orig.columns:
+                    if 'index' in columns:
                         self.rowpivots = ['index']
                         if 'index' in columns:
                             columns.remove('index')
@@ -66,17 +63,8 @@ class PerspectiveWidget(Widget):
         else:
             self.schema = {}
 
-        if data_src:
-            self.datasrc = data_src
-
         self._data = dat
 
-    # FIXME
-    data = property(_get_data, _set_data)
-    # @validate('_data')
-    # def _validate_data(self, proposal):
-    #     return proposal.value
-
     @validate('datasrc')
     def _validate_datasrc(self, proposal):
         datasrc = proposal.value
@@ -117,23 +105,22 @@ class PerspectiveWidget(Widget):
         sort = validate_sort(proposal.value)
         return sort
 
-    @validate('helper_config')
-    def _validate_helper_config(self, proposal):
-        conf = config(proposal.value, self._dat_orig, False)
-        return conf
+    def __del__(self):
+        self.send({'type': 'delete'})
 
-    def __init__(self, data, view='hypergrid', schema=None, columns=None, rowpivots=None, columnpivots=None, aggregates=None, sort=None, settings=True, dark=False, helper_config=None, **kwargs):
+    def __init__(self, data, view='hypergrid', schema=None, columns=None, rowpivots=None, columnpivots=None, aggregates=None, sort=None, settings=True, dark=False, *args, **kwargs):
         super(PerspectiveWidget, self).__init__(**kwargs)
+        self._helper = None
+        self.datasrc = 'static'
         self.view = validate_view(view)
         self.schema = schema or {}
         self.sort = validate_sort(sort) or []
         self.settings = settings
         self.dark = dark
-        self.helper_config = helper_config or {}
 
         self.rowpivots = validate_rowpivots(rowpivots) or []
         self.columnpivots = validate_columnpivots(columnpivots) or []
         self.aggregates = validate_aggregates(aggregates) or {}
 
         self.columns = validate_columns(columns) or []
-        self.data = data
+        self.load(data)
